<?php

class AdminProductsController extends AdminProductsControllerCore
{
	
	public function initFormCustomization($obj)
	{
		$data = $this->createTemplate($this->tpl_form);
		
		if ((bool)$obj->id)
		{
			if ($this->product_exists_in_shop)
			{   
				//El obj es el producto. 
				$labels = $obj->getCustomizationFields();
	
				$has_file_labels = (int)$this->getFieldValue($obj, 'uploadable_files');
				$has_text_labels = (int)$this->getFieldValue($obj, 'text_fields');
				$has_select_labels = (int)$this->getFieldValue($obj, 'select_fields');
				$data->assign(array(
						'obj' => $obj,
						'table' => $this->table,
						'languages' => $this->_languages,
						'has_file_labels' => $has_file_labels,
						'display_file_labels' => $this->_displayLabelFields($obj, $labels, $this->_languages, Configuration::get('PS_LANG_DEFAULT'), Product::CUSTOMIZE_FILE),
						'has_text_labels' => $has_text_labels,
						'display_text_labels' => $this->_displayLabelFields($obj, $labels, $this->_languages, Configuration::get('PS_LANG_DEFAULT'), Product::CUSTOMIZE_TEXTFIELD),
						'uploadable_files' => (int)($this->getFieldValue($obj, 'uploadable_files') ? (int)$this->getFieldValue($obj, 'uploadable_files') : '0'),
						'text_fields' => (int)($this->getFieldValue($obj, 'text_fields') ? (int)$this->getFieldValue($obj, 'text_fields') : '0'),
						'has_select_labels'=>$has_select_labels,
						'select_fields'=> (int)($this->getFieldValue($obj, 'select_fields') ? (int)$this->getFieldValue($obj, 'select_fields') : '0'),
						'display_select_labels' => $this->_displayLabelFields($obj, $labels, $this->_languages, Configuration::get('PS_LANG_DEFAULT'), Product::CUSTOMIZE_SELECTFIELD),
				));
			}
			else
				$this->displayWarning($this->l('You must save the product in this shop before adding customization.'));
		}
		else
			$this->displayWarning($this->l('You must save this product before adding customization.'));
	
		$this->tpl_form_vars['custom_form'] = $data->fetch();
	}
	
	public function setMedia(){
		parent::setMedia();
		//añadimos nuestro css
		$this->addCSS(__PS_BASE_URI__.'override/controllers/admin/css/myproductadmin.css', 'all');
	}
	
	
	protected function _displayLabelFields(&$obj, &$labels, $languages, $default_language, $type)
	{
		$content = '';
		$type = (int)($type);
		$labelGenerated = array(Product::CUSTOMIZE_FILE => (isset($labels[Product::CUSTOMIZE_FILE]) ? count($labels[Product::CUSTOMIZE_FILE]) : 0), 
								Product::CUSTOMIZE_TEXTFIELD => (isset($labels[Product::CUSTOMIZE_TEXTFIELD]) ? count($labels[Product::CUSTOMIZE_TEXTFIELD]) : 0),
								Product::CUSTOMIZE_SELECTFIELD => (isset($labels[Product::CUSTOMIZE_SELECTFIELD]) ? count($labels[Product::CUSTOMIZE_SELECTFIELD]) : 0),
								);
	
		$fieldIds = $this->_getCustomizationFieldIds($labels, $labelGenerated, $obj);
		if (isset($labels[$type]))
		foreach ($labels[$type] as $id_customization_field => $label){
			$content .= $this->_displayLabelField($label, $languages, $default_language, $type, $fieldIds, (int)($id_customization_field));
			//Si estamos ante un combo añadimos su textarea correspondiente multilenguaje
			if($type==Product::CUSTOMIZE_SELECTFIELD){
			
				$fieldsContainerName = 'comboContainer_'.$type.'_'.(int)($id_customization_field);
				$content .= '<div id="'.$fieldsContainerName.'" class="translatable clear comboContainer" style="line-height: 18px">';
				foreach ($languages as $language)
				{
					$comboName = 'combo_'.$type.'_'.(int)($id_customization_field).'_'.(int)($language['id_lang']);
					$comboText = (isset($label[(int)($language['id_lang'])])) ? $label[(int)($language['id_lang'])]['combo'] : '';
					$content .= '<div class="lang_'.$language['id_lang'].'" id="'.$comboName.'" style="display: '.((int)($language['id_lang']) == (int)($default_language) ? 'block' : 'none').'; clear: left; float: left; padding-bottom: 4px;">
								 <textarea  style="float: left" cols="40" rows="5" name="'.$comboName.'" >'.$comboText.'</textarea>
								</div>';
				}
				$content .='</div>';
			}
		}
			
		return $content;
	}
	
	
	
	protected function _getCustomizationFieldIds($labels, $alreadyGenerated, $obj)
	{
		$customizableFieldIds = array();
		if (isset($labels[Product::CUSTOMIZE_FILE]))
			foreach ($labels[Product::CUSTOMIZE_FILE] as $id_customization_field => $label)
				$customizableFieldIds[] = 'label_'.Product::CUSTOMIZE_FILE.'_'.(int)($id_customization_field);
		if (isset($labels[Product::CUSTOMIZE_TEXTFIELD]))
			foreach ($labels[Product::CUSTOMIZE_TEXTFIELD] as $id_customization_field => $label)
				$customizableFieldIds[] = 'label_'.Product::CUSTOMIZE_TEXTFIELD.'_'.(int)($id_customization_field);
		if (isset($labels[Product::CUSTOMIZE_SELECTFIELD]))
			foreach ($labels[Product::CUSTOMIZE_SELECTFIELD] as $id_customization_field => $label)
				$customizableFieldIds[] = 'label_'.Product::CUSTOMIZE_SELECTFIELD.'_'.(int)($id_customization_field);
		$j = 0;
		for ($i = $alreadyGenerated[Product::CUSTOMIZE_FILE]; $i < (int)($this->getFieldValue($obj, 'uploadable_files')); $i++)
			$customizableFieldIds[] = 'newLabel_'.Product::CUSTOMIZE_FILE.'_'.$j++;
		$j = 0;
		for ($i = $alreadyGenerated[Product::CUSTOMIZE_TEXTFIELD]; $i < (int)($this->getFieldValue($obj, 'text_fields')); $i++)
			$customizableFieldIds[] = 'newLabel_'.Product::CUSTOMIZE_TEXTFIELD.'_'.$j++;
		$j = 0;
		for ($i = $alreadyGenerated[Product::CUSTOMIZE_SELECTFIELD]; $i < (int)($this->getFieldValue($obj, 'select_fields')); $i++)
			$customizableFieldIds[] = 'newLabel_'.Product::CUSTOMIZE_SELECTFIELD.'_'.$j++;
		return implode('¤', $customizableFieldIds);
	}
	
	
	/*
	 * Se llama al guardar el tab de Personalización
	 */
	public function processCustomizationConfiguration()
	{
		$product = $this->object;
		// Get the number of existing customization fields ($product->text_fields is the updated value, not the existing value)
		$current_customization = $product->getCustomizationFieldIds();
		$files_count = 0;
		$text_count = 0;
		$select_count= 0;
		if (is_array($current_customization))
		{
			foreach ($current_customization as $field)
			{
				if ($field['type'] == 1)
					$text_count++;
				elseif ($field['type'] == 2)
					$select_count++;
				else 
					$files_count++;
			} 
		}
	
		if (!$product->createLabelsAndCombos((int)$product->uploadable_files - $files_count, (int)$product->text_fields - $text_count, (int)$product->select_fields - $select_count))
			$this->errors[] = Tools::displayError('An error occurred while creating customization fields.');
		if (!count($this->errors) && !$product->updateLabelsAndCombos())
			$this->errors[] = Tools::displayError('An error occurred while updating customization fields.');
		$product->customizable = ($product->uploadable_files > 0 || $product->text_fields > 0 || $product->select_fields > 0) ? 1 : 0;
		if (!count($this->errors) && !$product->update())
			$this->errors[] = Tools::displayError('An error occurred while updating the custom configuration.');
	}
	
	
}

